@@ -61,8 +61,10 @@ int RUNMAIN(arckill)(int argc, char **argv) {
     return 1;
   }
 
-  if (!checkproxy(usercfg)) {
-    return 1;
+  if(usercfg.OToken().empty()) {
+    if (!checkproxy(usercfg)) {
+      return 1;
+    }
   }
 
   if (opt.debug.empty() && !usercfg.Verbosity().empty())
