@@ -96,7 +96,7 @@ static int runmain(int argc, char **argv) {
 
   setlocale(LC_ALL, "");
 
-  Arc::LogStream logcerr(std::cerr);
+  static Arc::LogStream logcerr(std::cerr);
   logcerr.setFormat(Arc::ShortFormat);
   Arc::Logger::getRootLogger().addDestination(logcerr);
   Arc::Logger::getRootLogger().setThreshold(Arc::WARNING);
