@@ -75,7 +75,7 @@ PDPServiceInvoker::PDPServiceInvoker(Config* cfg,Arc::PluginArgument* parg):PDP(
   client = new Arc::ClientSOAP(mcc_cfg,url,60);
 }
 
-bool PDPServiceInvoker::isPermitted(Message *msg) const {
+PDPStatus PDPServiceInvoker::isPermitted(Message *msg) const {
   if((!is_xacml) && is_saml) {
     logger.msg(ERROR,"Arc policy can not been carried by SAML2.0 profile of XACML");
     return false;
@@ -99,7 +99,7 @@ bool PDPServiceInvoker::isPermitted(Message *msg) const {
   };
   if(cauth) {
     if(!cauth->Export(is_xacml? SecAttr::XACML : SecAttr::ARCAuth,requestxml)) {
-      delete mauth;
+      delete cauth;
       logger.msg(ERROR,"Failed to convert security information to ARC request");
       return false;
     };
@@ -208,6 +208,7 @@ bool PDPServiceInvoker::isPermitted(Message *msg) const {
 }
 
 PDPServiceInvoker::~PDPServiceInvoker(){
+  if(client != NULL) delete client;
 }
 
 } // namespace ArcSec
