@@ -35,21 +35,15 @@ common_init () {
     # init common LRMS environmental variables
     init_lrms_env
     # optionally enable support for community RTEs
-    [ -e "${pkgdatadir}/community_rtes.sh" ] && source "${pkgdatadir}/community_rtes.sh"
+    [ -e "${pkgdatadir}/community_rtes.sh" ] && . "${pkgdatadir}/community_rtes.sh"
 }
 
-# defines failures_file
-define_failures_file () {
-    failures_file="$joboption_controldir/job.$joboption_gridid.failed"
-}
-
-
 # checks any scratch is defined (shared or local)
 check_any_scratch () {
     if [ -z "${RUNTIME_NODE_SEES_FRONTEND}" ] ; then
         if [ -z "${RUNTIME_LOCAL_SCRATCH_DIR}" ] ; then
             echo "Need to know at which directory to run job: RUNTIME_LOCAL_SCRATCH_DIR must be set if RUNTIME_NODE_SEES_FRONTEND is empty" 1>&2
-            echo "Submission: Configuration error.">>"$failures_file"
+            echo "Submission: Configuration error."
             exit 1
         fi
     fi
@@ -433,7 +427,7 @@ RTE_stage0 () {
             # run RTE stage 0
             # WARNING!!! IN SOME CASES DUE TO DIRECT SOURCING OF RTE SCRIPT WITHOUT ANY SAFETY CHECKS 
             #            SPECIALLY CRAFTED RTES CAN BROKE CORRECT SUBMISSION (e.g. RTE redefine 'rte_idx' variable)
-            [ -e "${rte_params_path}" ] && source "${rte_params_path}" 1>&2
+            [ -e "${rte_params_path}" ] && . "${rte_params_path}" 1>&2
             # prepare RUNTIME_JOB_SWDIR for community-defined RTE software
             [ -n "${COMMUNITY_RTES}" ] && community_software_prepare
             # execute RTE script stage 0
@@ -706,10 +700,10 @@ EOSCR
   if [ -z "$joboption_benchmark" ]; then
      joboption_benchmark="HEPSPEC:1.0"
      if [ -n "$CONFIG_benchmark" ]; then
-        if [ "$CONFIG_benchmark" == "__array__" ]; then
-          joboption_benchmark="${CONFIG_benchmark_0// /:}"
-        else
-          joboption_benchmark="${CONFIG_benchmark// /:}"
+         if [ "$CONFIG_benchmark" = "__array__" ]; then
+	  joboption_benchmark=$(printf '%s' "${CONFIG_benchmark_0}" | tr ' ' ':') 
+         else
+	  joboption_benchmark=$(printf '%s' "${CONFIG_benchmark}" | tr ' ' ':') 
         fi
      fi
   fi
