@@ -47,7 +47,7 @@ static void subst_arg(std::string& str,void* arg) {
 void func(void) {
 }
 
-int AuthUser::match_plugin(const char* line) {
+AuthResult AuthUser::match_plugin(const char* line) {
   // return AAA_NO_MATCH;
   if(!line) return AAA_NO_MATCH;
   for(;*line;line++) if(!isspace(*line)) break;
@@ -74,6 +74,6 @@ int AuthUser::match_plugin(const char* line) {
   };
   logger.msg(Arc::INFO,"Plugin %s printed: %u",run.cmd(),run.stdout_channel());
   logger.msg(Arc::ERROR,"Plugin %s error: %u",run.cmd(),run.stderr_channel());
-  return AAA_NO_MATCH; // It is safer to return no-match
+  return AAA_NO_MATCH; // It is safer to return no-match (??)
 }
 
